package edu.pacificu.cs.chadd;
/*
* Creates an Animal class.
* 
* @author $Author: chadd $
* 
* @version $Revision: 76 $ $Date: 2011-03-28 11:05:01 -0700 (Mon, 28 Mar 2011) $
* 
* @since 1.0
*/

public abstract class Animal {

	private int  weight;
	
	/**
	 * Initialized data members to default values
	 * 
	 * @since 1.0
	 */
	public Animal()
	{
		weight = -1;
	}
	
	/**
	 * Initialized data members using parameter
	 * 
	 * @param w		the weight of the animal
	 * 
	 * @since 1.0
	 */
	public Animal(int w)
	{
		weight = w;
	}
	
	/**
	 * Print a text message to the screen representing the sound this
	 * animal makes.  This is an abstract method and must be implemented
	 * by subclasses.
	 * 
	 * @since 1.0
	 */
	abstract public void makeSound();

	/**
	 * Returns the weight of an animal.  This method is abstract to allow 
	 * subclasses to override it.
	 * 
	 * @return the weight of the animal
	 * 
	 * @since 1.0
	 */
	abstract public int getWeight2();
	
	/**
	 * Print "hi" to the screen
	 * 
	 * @since 1.0
	 */
	public void hi()
	{
		System.err.println("hi");
	}
	
	/**
	 * Return the weight of the animal
	 * 
	 * @return the weight of the animal
	 * 
	 * @since 1.0
	 */
	public int getWeight()
	{
		return weight;
	}
	
	/**
	 * Allow one animal to eat another animal.  The eaten animal has its weight
	 * ste to 0 and the animal doing the eating gains 90% of the weight of the
	 * eaten animal.
	 * 
	 * @param food 	the animal being eaten
	 *  
	 * @return the new weight of the animal doing the eating
	 * 
	 * @since 1.0
	 */
	public int eat(Animal food)
	{
		weight += food.getWeight() * 0.9;
		food.setWeight(0);
		return weight;
	}
	
	/**
	 * Set the weight of the animal
	 * 
	 * @param w the weight of the animal
	 * 
	 * @since 1.0
	 */
	public void setWeight(int w)
	{
		weight = w;
	}
}
